Best Practices
==============

The Dask community maintains a
`general Dask best practices page <https://docs.dask.org/en/latest/best-practices.html>`_,
as well as separate best practices pages for working with individual Dask
collections:

- `Dask Array best practices <https://docs.dask.org/en/latest/array-best-practices.html>`_
- `Dask DataFrame best practices <https://docs.dask.org/en/latest/dataframe-best-practices.html>`_
- `Dask Delayed best practices <https://docs.dask.org/en/latest/delayed-best-practices.html>`_

It's generally recommended to use Dask best practices with your Coiled workloads.
